@@ -46,7 +46,7 @@ def convert_to_batch(reading_files: List[Path],
 def publish(add_status_creator, config: Config):
     publish_config = config.pvoutput_publish_options
     system_details = SystemDetails(api_key=publish_config.secret_api_key, system_id=str(publish_config.system_id))
-    cache = FileProcessCache(determine_cache_path(config), publish_config.completed_path)
+    cache = FileProcessCache(determine_cache_path(config))
     reading_files = cache.load()
 
     if cache.size() > 1:
